pub struct Config {
glob_sets: BTreeMap<String, Vec<String>>,
pub(crate) rules: BTreeMap<String, RuleConfig>,
workspace: WorkspaceContext,
}Expand description
Top-level tidy configuration loaded from tidy.toml.
Fields
glob_sets: BTreeMap<String, Vec<String>>rules: BTreeMap<String, RuleConfig>workspace: WorkspaceContextImplementations
Sourceimpl Config
impl Config
Sourcepub fn load(path: &Path) -> Result<Config, ConfigError>
pub fn load(path: &Path) -> Result<Config, ConfigError>
Load, parse, and resolve a config file (expands glob set references).
Errors
Returns an error when the file cannot be read, parsed, or resolved against its glob sets.
pub fn is_enabled(&self, name: &str) -> bool
pub fn ignore_patterns(&self, name: &str) -> &[String]
pub fn get_str_array(&self, rule: &str, param: &RuleParam) -> Vec<String>
Sourcepub fn validate(
&self,
registered: &[(&str, &'static [RuleParam])],
) -> (Vec<String>, Vec<String>)
pub fn validate( &self, registered: &[(&str, &'static [RuleParam])], ) -> (Vec<String>, Vec<String>)
Validate config against registered rules, returning (errors, warnings).
pub fn backfill_defaults(&mut self, registered: &[(&str, &'static [RuleParam])])
pub fn generate_default(registered: &[(&str, &'static [RuleParam])]) -> Config
Sourcepub fn to_toml_string(&self) -> String
pub fn to_toml_string(&self) -> String
Serializes this configuration with the standard explanatory header.
Panics
Panics if the resolved configuration cannot be serialized as TOML.
Sourcepub fn resolved_rules(&self, rules: &[RuleMeta]) -> Vec<ConfigRule>
pub fn resolved_rules(&self, rules: &[RuleMeta]) -> Vec<ConfigRule>
Merge resolved configuration with registered rule metadata.
pub(crate) fn get_i64(&self, rule: &str, param: &RuleParam) -> i64
pub(crate) fn get_u64(&self, rule: &str, param: &RuleParam) -> u64
pub(crate) fn get_usize(&self, rule: &str, param: &RuleParam) -> usize
pub(crate) fn workspace(&self) -> &WorkspaceContext
fn resolve(raw: RawConfig) -> Result<Config, ConfigError>
fn validate_param( rule: &str, param: &RuleParam, cfg: &RuleConfig, errors: &mut Vec<String>, )